@@ -31,17 +31,33 @@ while [ $# -gt 0 ]; do
   esac
 done
 
-DEBUG=1 HAVE_MSGPACK=1 run make -j$(nproc) > /dev/null
-run make install > /dev/null
+if [ "${SUPPRESS_LOG:-yes}" = "yes" ]; then
+  OUTPUT="> /dev/null"
+else
+  OUTPUT=""
+fi
+
+: ${PG_CONFIG:=pg_config}
+
+export PGRN_DEBUG=1
+export HAVE_MSGPACK=1
+eval "run make -j$(nproc) PG_CONFIG=${PG_CONFIG} ${OUTPUT}"
+if [ "${NEED_SUDO:-no}" = "yes" ]; then
+  eval "run sudo -H make PG_CONFIG=${PG_CONFIG} install ${OUTPUT}"
+else
+  eval "run make PG_CONFIG=${PG_CONFIG} install ${OUTPUT}"
+fi
 export PG_REGRESS_DIFF_OPTS="-u --color=always"
 launcher="--launcher=$(pwd)/test/short-pgappname"
 if [ -n "${test_names}" ]; then
   make installcheck \
        EXTRA_REGRESS_OPTS="${launcher}" \
+       PG_CONFIG="${PG_CONFIG}" \
        REGRESS="${test_names}"
 else
   make installcheck \
-       EXTRA_REGRESS_OPTS="${launcher}"
+       EXTRA_REGRESS_OPTS="${launcher}" \
+       PG_CONFIG="${PG_CONFIG}"
 fi
 success=$?
 if [ $success != 0 ]; then
